@@ -92,7 +92,9 @@ class JSONRPCSite:
         https://github.com/pallets/werkzeug/blob/master/src/werkzeug/wrappers/json.py#L54
         """
         mt = request.mimetype
-        return mt == 'application/json' or mt.startswith('application/') and mt.endswith('+json')
+        return mt in ('application/json', 'application/json-rpc', 'application/jsonrequest') or (
+            mt.startswith('application/') and mt.endswith('+json')
+        )
 
     def register(self, name: str, view_func: Callable[..., Any]) -> None:
         self.view_funcs[name] = view_func
