@@ -24,6 +24,7 @@
 # CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
+import json
 import uuid
 from typing import Any, Dict, List, Tuple
 
@@ -86,6 +87,30 @@ def test_app_create():
         assert rv.json == {'id': 1, 'jsonrpc': '2.0', 'result': 'Foo :)'}
         assert rv.status_code == 200
 
+        rv = client.post(
+            '/api',
+            data=json.dumps({'id': 1, 'jsonrpc': '2.0', 'method': 'app.index'}),
+            headers={'Content-Type': 'application/json-rpc'},
+        )
+        assert rv.json == {'id': 1, 'jsonrpc': '2.0', 'result': 'Welcome to Flask JSON-RPC'}
+        assert rv.status_code == 200
+
+        rv = client.post(
+            '/api',
+            data=json.dumps({'id': 1, 'jsonrpc': '2.0', 'method': 'app.index', 'params': []}),
+            headers={'Content-Type': 'application/jsonrequest'},
+        )
+        assert rv.json == {'id': 1, 'jsonrpc': '2.0', 'result': 'Welcome to Flask JSON-RPC'}
+        assert rv.status_code == 200
+
+        rv = client.post(
+            '/api',
+            data=json.dumps({'id': 1, 'jsonrpc': '2.0', 'method': 'app.index', 'params': []}),
+            headers={'Content-Type': 'application/json'},
+        )
+        assert rv.json == {'id': 1, 'jsonrpc': '2.0', 'result': 'Welcome to Flask JSON-RPC'}
+        assert rv.status_code == 200
+
 
 def test_app_create_without_register_app():
     app = Flask('test_app', instance_relative_config=True)
