@@ -24,6 +24,7 @@
 # CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
+import json
 
 
 def test_app_greeting(client):
@@ -42,6 +43,32 @@ def test_app_greeting(client):
     assert rv.status_code == 200
 
 
+def test_app_greeting_with_different_content_types(client):
+    rv = client.post(
+        '/api',
+        data=json.dumps({'id': 1, 'jsonrpc': '2.0', 'method': 'jsonrpc.greeting'}),
+        headers={'Content-Type': 'application/json-rpc'},
+    )
+    assert rv.json == {'id': 1, 'jsonrpc': '2.0', 'result': 'Hello Flask JSON-RPC'}
+    assert rv.status_code == 200
+
+    rv = client.post(
+        '/api',
+        data=json.dumps({'id': 1, 'jsonrpc': '2.0', 'method': 'jsonrpc.greeting', 'params': ['Python']}),
+        headers={'Content-Type': 'application/jsonrequest'},
+    )
+    assert rv.json == {'id': 1, 'jsonrpc': '2.0', 'result': 'Hello Python'}
+    assert rv.status_code == 200
+
+    rv = client.post(
+        '/api',
+        data=json.dumps({'id': 1, 'jsonrpc': '2.0', 'method': 'jsonrpc.greeting', 'params': {'name': 'Flask'}}),
+        headers={'Content-Type': 'application/json'},
+    )
+    assert rv.json == {'id': 1, 'jsonrpc': '2.0', 'result': 'Hello Flask'}
+    assert rv.status_code == 200
+
+
 def test_app_greeting_raise_parse_error(client):
     rv = client.post('/api', data={'id': 1, 'jsonrpc': '2.0', 'method': 'jsonrpc.greeting'})
     assert rv.json == {
